@@ -1,11 +1,8 @@
 """Admin classes for the ``multilingual_initiatives`` app."""
 from django.contrib import admin
-from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
-from django_libs.admin import MultilingualPublishMixin
-from simple_translation.admin import TranslationAdmin
-from simple_translation.utils import get_preferred_translation_from_lang
+from hvad.admin import TranslatableAdmin
 
 from .models import Initiative, InitiativePersonRole
 
@@ -15,16 +12,20 @@ class InitiativePersonRoleInline(admin.TabularInline):
     model = InitiativePersonRole
 
 
-class InitiativeAdmin(MultilingualPublishMixin, TranslationAdmin):
+class InitiativeAdmin(TranslatableAdmin):
     """Admin for the ``Initiative`` model."""
     inlines = [InitiativePersonRoleInline]
-    list_display = ['title', 'phone', 'website', 'start_date', 'end_date',
-                    'description_short', 'organization', 'is_published']
+    list_display = ['get_title', 'phone', 'website', 'start_date', 'end_date',
+                    'description_short', 'organization', 'get_is_published']
 
-    def title(self, obj):
-        lang = get_language()
-        return get_preferred_translation_from_lang(obj, lang).title
-    title.short_description = _('Title')
+    def get_title(self, obj):
+        return obj.title
+    get_title.short_description = _('Title')
+
+    def get_is_published(self, obj):
+        return obj.is_published
+    get_is_published.short_description = _('Title')
+    get_is_published.boolean = True
 
     def description_short(self, obj):
         if len(obj.description) > 40:
